@@ -33,7 +33,7 @@ class RTStructBuilder:
         RTStructBuilder.validate_rtstruct(ds)
         RTStructBuilder.validate_rtstruct_series_references(ds, series_data)
 
-        # TODO create new frame of reference? Right now we assume the last frame of reference created is suitable 
+        # TODO create new frame of reference? Right now we assume the last frame of reference created is suitable
         return RTStruct(series_data, ds)
 
     @staticmethod
@@ -42,10 +42,12 @@ class RTStructBuilder:
         Method to validate a dataset is a valid RTStruct containing the required fields
         """
 
-        if ds.SOPClassUID != SOPClassUID.RTSTRUCT or \
-                not hasattr(ds, 'ROIContourSequence') or \
-                not hasattr(ds, 'StructureSetROISequence') or \
-                not hasattr(ds, 'RTROIObservationsSequence'):
+        if (
+            ds.SOPClassUID != SOPClassUID.RTSTRUCT
+            or not hasattr(ds, "ROIContourSequence")
+            or not hasattr(ds, "StructureSetROISequence")
+            or not hasattr(ds, "RTROIObservationsSequence")
+        ):
             raise Exception("Please check that the existing RTStruct is valid")
 
     @staticmethod
@@ -55,17 +57,20 @@ class RTStructBuilder:
         """
         for refd_frame_of_ref in ds.ReferencedFrameOfReferenceSequence:
             # Study sequence references are optional so return early if it does not exist
-            if 'RTReferencedStudySequence' not in refd_frame_of_ref:
+            if "RTReferencedStudySequence" not in refd_frame_of_ref:
                 return
 
             for rt_refd_study in refd_frame_of_ref.RTReferencedStudySequence:
                 for rt_refd_series in rt_refd_study.RTReferencedSeriesSequence:
                     for contour_image in rt_refd_series.ContourImageSequence:
                         RTStructBuilder.validate_contour_image_in_series_data(
-                            contour_image, series_data)
+                            contour_image, series_data
+                        )
 
     @staticmethod
-    def validate_contour_image_in_series_data(contour_image: Dataset, series_data: List[Dataset]):
+    def validate_contour_image_in_series_data(
+        contour_image: Dataset, series_data: List[Dataset]
+    ):
         """
         Method to validate that the ReferencedSOPInstanceUID of a given contour image exists within the series data
         """
@@ -75,6 +80,6 @@ class RTStructBuilder:
 
         # ReferencedSOPInstanceUID is NOT available
         raise Exception(
-            f'Loaded RTStruct references image(s) that are not contained in input series data. ' +
-            f'Problematic image has SOP Instance Id: {contour_image.ReferencedSOPInstanceUID}'
+            f"Loaded RTStruct references image(s) that are not contained in input series data. "
+            + f"Problematic image has SOP Instance Id: {contour_image.ReferencedSOPInstanceUID}"
         )
